﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/EC2_EXPORTS.h>

namespace Aws {
namespace EC2 {
namespace Model {
enum class CapacityManagerDataExportStatus { NOT_SET, pending, in_progress, delivered, failed };

namespace CapacityManagerDataExportStatusMapper {
AWS_EC2_API CapacityManagerDataExportStatus GetCapacityManagerDataExportStatusForName(const Aws::String& name);

AWS_EC2_API Aws::String GetNameForCapacityManagerDataExportStatus(CapacityManagerDataExportStatus value);
}  // namespace CapacityManagerDataExportStatusMapper
}  // namespace Model
}  // namespace EC2
}  // namespace Aws
